@@ -1,8 +1,7 @@
 package Search::OpenSearch::Server::Plack;
-
-use warnings;
-use strict;
-use base qw( Search::OpenSearch::Server Plack::Component );
+use Moose;
+extends 'Plack::Component';
+with 'Search::OpenSearch::Server';
 use Carp;
 use Search::OpenSearch;
 use Search::OpenSearch::Result;
@@ -12,35 +11,7 @@ use JSON;
 use Scalar::Util qw( weaken );
 use Time::HiRes qw( time );
 
-our $VERSION = '0.28';
-
-sub prepare_app {
-    my $self = shift;
-    $self->setup_engine();
-}
-
-sub setup_engine {
-    my $self = shift;
-    if ( defined $self->engine ) {
-        return 1;
-    }
-    if ( defined $self->engine_config ) {
-
-        # this appears to correctly defer creation
-        # till each child is created, regardless of -L Delayed
-        # So nice when code Just Works.
-        #warn "[$$] engine created";
-
-        $self->engine(
-            Search::OpenSearch->engine(
-                logger => $self,
-                %{ $self->engine_config },
-            )
-        );
-        return 1;
-    }
-    croak "engine() or engine_config() required";
-}
+our $VERSION = '0.300';
 
 sub log {
     my $self = shift;
@@ -81,17 +52,17 @@ sub call {
     }
 }
 
-sub do_search {
-    my ( $self, $req, $response ) = @_;
-    $self->SUPER::do_search( $req, $response );
+around 'do_search' => sub {
+    my ( $orig, $self, $req, $response ) = @_;
+    $self->$orig( $req, $response );
     return $response->finalize();
-}
+};
 
-sub do_rest_api {
-    my ( $self, $req, $response ) = @_;
-    $self->SUPER::do_rest_api( $req, $response );
+around 'do_rest_api' => sub {
+    my ( $orig, $self, $req, $response ) = @_;
+    $self->$orig( $req, $response );
     return $response->finalize();
-}
+};
 
 1;
 
@@ -150,12 +121,11 @@ Inherits from Plack::Component. I<params> can be:
 
 =item engine
 
-A Search::OpenSearch::Engine instance. Either this or B<engine_config> is required.
+Should be a L<Search::OpenSearch::Engine> instance. 
 
 =item engine_config
 
 A hashref passed to the Search::OpenSearch->engine method.
-Either this or B<engine> is required.
 
 =item stats_logger
 
@@ -175,15 +145,6 @@ instantiate a L<Plack::Request> and pass it into do_search().
 
 Passes I<msg> on to the Plack::Request->logger object, if any.
 
-=head2 prepare_app
-
-Calls setup_engine().
-
-=head2 setup_engine
-
-Instantiates the Search::OpenSearch::Engine, if necessary, using
-the values set in engine_config().
-
 =head2 do_rest_api( I<request>, I<response> )
 
 Overrides base Server method to call finalize() on I<response>.
